==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CATEGORY","O");

define("_LVOTES","벼@");
define("_HITS","Hits");
define("_TOPWELCOME","wӨƦ]");
define("_READSTORIES","̨w諸");
define("_COMMENTEDSTORIES","̨㪧ĳʪ");
define("_ACTIVECAT","̬DO");
define("_READSECTION","̨w諸M");
define("_NEWSSUBMITTERS","̬DsD뻼");
define("_NEWSSENT","sDHe");
define("_VOTEDPOLLS","oƳ̦h벼լd");
define("_MOSTACTIVEAUTHORS","̬D@");
define("_NEWSPUBLISHED","sDo");
define("_READREVIEWS","̨w諸@~");
define("_DOWNLOADEDFILES","̱`QUɮ");
define("_MOSTREADPAGES","̱`Q\Ū");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Top/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CATEGORY","O");

define("_LVOTES","벼@");
define("_HITS","I");
define("_TOPWELCOME","wӨƦ]");
define("_READSTORIES","̨w諸");
define("_COMMENTEDSTORIES","̨㪧ĳʪ");
define("_ACTIVECAT","̬DO");
define("_READSECTION","̨w諸M");
define("_NEWSSUBMITTERS","̬DsD뻼");
define("_NEWSSENT","sDHe");
define("_VOTEDPOLLS","oƳ̦h벼լd");
define("_MOSTACTIVEAUTHORS","̬D@");
define("_NEWSPUBLISHED","sDo");
define("_READREVIEWS","̨w諸@~");
define("_DOWNLOADEDFILES","̱`QUɮ");
define("_MOSTREADPAGES","̱`Q\Ū");
define("_MOSTVOTEDSTORIES","̦h諸");
define("_POINTS","I");
define("_BESTRATEDSTORIES","襤̦n (̦h5I)");

?>
